==> clawiz-bpm-common-2.2.0-sources.jar: org/clawiz/bpm/common/generator/type/component/element/BpmTypeServiceSaveMethodElementExtension.java <==
/*
 *
 *  * MIT License
 *  *
 *  * Copyright (c) 2018 Clawiz
 *  *
 *  * Permission is hereby granted, free of charge, to any person obtaining a copy
 *  * of this software and associated documentation files (the "Software"), to deal
 *  * in the Software without restriction, including without limitation the rights
 *  * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  * copies of the Software, and to permit persons to whom the Software is
 *  * furnished to do so, subject to the following conditions:
 *  *
 *  * The above copyright notice and this permission notice shall be included in all
 *  * copies or substantial portions of the Software.
 *  *
 *  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  * SOFTWARE.
 *  *
 *
 */

package org.clawiz.bpm.common.generator.type.component.element;

import org.clawiz.bpm.common.metadata.data.process.Process;
import org.clawiz.bpm.common.metadata.data.process.ProcessList;
import org.clawiz.core.common.system.service.extension.ServiceExtensionMethod;
import org.clawiz.core.common.utils.StringUtils;

import static org.clawiz.core.common.system.type.generator.component.service.element.save.TypeServiceSaveMethodElement.AFTER_SAVE_EXTENSION_NAME;

public class BpmTypeServiceSaveMethodElementExtension extends AbstractBpmTypeServiceMethodElementExtension {

    @ServiceExtensionMethod(name = AFTER_SAVE_EXTENSION_NAME)
    public void afterSave() {

        ProcessList processes = processGeneratorHelper.getProcessesByRootType(getGenerator().getType());
        if ( processes.size() == 0 ) {
            return;
        }

        String oldObjectName = "old" + StringUtils.toUpperFirstChar(getGenerator().getTypeJavaVariableName());

        boolean found = false;
        for ( Process process : processes ) {
            if ( ! process.isStartOnNew() ) {
                continue;
            }
            if ( ! found ) {
                found = true;
                addText("if ( " + oldObjectName + " == null ) {");
            }
            addText("    getService(" + process.getServicePackageName() + "." + process.getServiceClassName() + ".class)"
                    + ".startProcess(" + getGenerator().getTypeJavaVariableName() +  ".getId());");
        }

        if ( found ) {
            addText("}");
        }

    }

}

==> clawiz-bpm-common-2.2.2-sources.jar: org/clawiz/bpm/common/generator/type/component/element/BpmTypeServiceSaveMethodElementExtension.java <==
/*
 *
 *  * MIT License
 *  *
 *  * Copyright (c) 2018 Clawiz
 *  *
 *  * Permission is hereby granted, free of charge, to any person obtaining a copy
 *  * of this software and associated documentation files (the "Software"), to deal
 *  * in the Software without restriction, including without limitation the rights
 *  * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  * copies of the Software, and to permit persons to whom the Software is
 *  * furnished to do so, subject to the following conditions:
 *  *
 *  * The above copyright notice and this permission notice shall be included in all
 *  * copies or substantial portions of the Software.
 *  *
 *  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  * SOFTWARE.
 *  *
 *
 */

package org.clawiz.bpm.common.generator.type.component.element;

import org.clawiz.bpm.common.metadata.data.process.Process;
import org.clawiz.bpm.common.metadata.data.process.ProcessList;
import org.clawiz.core.common.system.service.extension.ServiceExtensionMethod;
import org.clawiz.core.common.utils.StringUtils;

import static org.clawiz.core.common.system.type.generator.component.service.element.save.TypeServiceSaveMethodElement.AFTER_SAVE_EXTENSION_NAME;

public class BpmTypeServiceSaveMethodElementExtension extends AbstractBpmTypeServiceMethodElementExtension {

    @ServiceExtensionMethod(name = AFTER_SAVE_EXTENSION_NAME)
    public void afterSave() {

        ProcessList processes = processGeneratorHelper.getProcessesByRootType(getGenerator().getType());
        if ( processes.size() == 0 ) {
            return;
        }

        String oldObjectName = "old" + StringUtils.toUpperFirstChar(getGenerator().getTypeJavaVariableName());

        boolean found = false;
        for ( Process process : processes ) {
            if ( process.isStartOnNew() == null || ! process.isStartOnNew() ) {
                continue;
            }
            if ( ! found ) {
                found = true;
                addText("if ( " + oldObjectName + " == null ) {");
            }
            addText("    getService(" + process.getServicePackageName() + "." + process.getServiceClassName() + ".class)"
                    + ".startProcess(" + getGenerator().getTypeJavaVariableName() +  ".getId());");
        }

        if ( found ) {
            addText("}");
        }

    }

}
